@@ -111,13 +111,30 @@ def test_walk_leaves():
 
 
 def test_dict_obj():
+    import pytest
     from pythonic_toolbox.utils.dict_utils import DictObj
 
+    naive_dct = {
+        'key1': 'val1',
+        'key2': 'val2',
+    }
+
+    obj = DictObj(naive_dct)
+    # same behavior like ordinary dict according to the python version (FILO for popitem for 3.6+)
+    assert obj.popitem() == ('key2', 'val2')
+    assert obj.popitem() == ('key1', 'val1')
+    with pytest.raises(KeyError) as __:
+        obj.popitem()
+    obj.key3 = 'val3'
+    assert obj.pop('key3', None) == 'val3'
+    assert obj.pop('key4', None) is None
+
     person_dct = {'name': 'Albert', 'age': '34', 'sex': 'Male', 'languages': ['Chinese', 'English']}
 
     person = DictObj(person_dct)
     assert person.to_dict() == person_dct
     assert set(person.keys()) == {'name', 'age', 'sex', 'languages'}
+    assert hasattr(person, 'name') is True
     assert person.name == 'Albert'
     assert person['name'] == 'Albert'
     person.languages.append('Japanese')
@@ -127,12 +144,15 @@ def test_dict_obj():
     assert person['height'] == '170'
     assert 'height' in person
     assert 'height' in person.keys()
+    assert hasattr(person, 'height') is True
     del person['height']
     assert 'height' not in person
     assert 'height' not in person.keys()
     person['height'] = '170cm'
 
     person.update({'weight': '50'})
+    weight_val = person.pop('weight')
+    assert weight_val == '50'
     person.update(DictObj({'weight': '50kg'}))
     assert person.weight == '50kg'
 
@@ -164,6 +184,12 @@ def test_final_dict_obj():
     expected_error_str = 'Not allowed to assign attribute name with value Steve for an initialized FinalDictObj'
     assert exec_info.value.args[0] == expected_error_str
 
+    with pytest.raises(RuntimeError) as __:
+        fixed_person.popitem()
+
+    with pytest.raises(RuntimeError) as __:
+        fixed_person.pop('name')
+
     assert type(fixed_person.languages) == tuple
     with pytest.raises(AttributeError) as exec_info:
         # list values are changed into tuple to avoid being modified
